@@ -41,6 +41,7 @@ CScoresheet::CScoresheet(QWidget *win_)
 	loadingFile = false;
 	defaultName = "Player ";
 	defaultDirectory = "/home/user/MyDocs";
+	lastFileName = "scores.csv";
 	
 	for(int i=0; i<sizeX; i++)
 	{
@@ -196,7 +197,8 @@ CScoresheet::CScoresheet(QWidget *win_)
 	dlg_about = new QDialog(win,Qt::Dialog);
 	dlg_about->setWindowTitle("About");
 	QHBoxLayout *abt_hbox = new QHBoxLayout(dlg_about);
-	QLabel *aboutl = new QLabel("Scoresheet version "+VERSION+" by Heikki Holstila",dlg_about);
+	QLabel *aboutl = new QLabel("Scoresheet version "+PROGRAM_VERSION+" by Heikki Holstila",dlg_about);
+	aboutl->setWordWrap(true);
 	abt_hbox->addWidget(aboutl);
 
 	progress = new QProgressBar(win);
@@ -446,7 +448,7 @@ void CScoresheet::playersNumChanged(int num)
 		{
 			s.setNum(i+count+1);
 			stp_list->addItem(defaultName+s);
-			stp_list->item(i+count)->setFlags(stp_list->item(i+count)->flags() | Qt::ItemIsEditable);			
+			stp_list->item(i+count)->setFlags(stp_list->item(i+count)->flags() | Qt::ItemIsEditable);
 		}
 	}
 }
@@ -494,14 +496,16 @@ void CScoresheet::createSetup()
 void CScoresheet::save()
 {
 	QString fname = QFileDialog::getSaveFileName(win, "Save file",
-		defaultDirectory, "Comma Separated Values (*.csv)");
+		defaultDirectory+"/"+lastFileName, "Comma Separated Values (*.csv)");
 		
 	if( fname!=NULL && !fname.endsWith(".csv") )
 		fname.append(".csv");
 	
-	QStringList fileNames;
 	if( fname != NULL  )
 	{
+		defaultDirectory = fname.section("/",0,-2);
+		lastFileName = fname.section("/",-1);
+
 		CCSVFile csv( fname );
 		
 		csv.appendRow(names);
@@ -536,6 +540,9 @@ void CScoresheet::load()
 
 	if( fname != NULL )
 	{
+		defaultDirectory = fname.section("/",0,-2);
+		lastFileName = fname.section("/",-1);
+		
 		CCSVFile csv( fname );
 		
 		if( !csv.load() ) {
@@ -562,7 +569,7 @@ void CScoresheet::load()
 		resizeTable();
 		loadingFile = true;
 
-		progress->setRange(0,sizeX*sizeY);
+		progress->setRange(0,sizeX);
 		progress->setValue(0);
 		keys->hide();
 		barH->hide();
@@ -581,8 +588,8 @@ void CScoresheet::load()
 					table->item(j,i)->setTextAlignment(Qt::AlignCenter);
 				}
 				if( t.length()>0 ) table->item(j,i)->setText(t);
-				progress->setValue(sizeX*j+i);
 			}
+			progress->setValue(i);
 		}
 
    		progress->hide();
@@ -596,179 +603,3 @@ void CScoresheet::load()
 }
 
 
-/*
-void CScoresheet::save()
-{
-	dlg_file->setWindowTitle("Save file");
-	dlg_file->setFileMode(QFileDialog::AnyFile);
-	dlg_file->setAcceptMode(QFileDialog::AcceptSave);
-	
-	QStringList fileNames;
-	if( dlg_file->exec() )
-	{
-		fileNames = dlg_file->selectedFiles();
-		
-		QFile file(fileNames.at(0), win);
-		if( !file.open(QIODevice::WriteOnly | QIODevice::Text) ) {
-			QMaemo5InformationBox::information ( win, "Could not open file for writing!",
-				QMaemo5InformationBox::DefaultTimeout );
-			return;
-		}		
-		QTextStream out(&file);
-
-		//out << "ScoresheetSizeXY," << sizeX << "," << sizeY << "\n";
-		for( int i=0; i<names.count(); i++ )
-		{
-			QString s = names.at(i);
-			s.replace("\"","");
-			if( s=="," ) s="";
-			out << "\"" << s << "\"";
-			if( i==names.count()-1 )
-				out << "\n";
-			else
-				out << ",";
-		}
-		
-		for( int i=0; i<table->rowCount(); i++ )
-		{
-			for( int j=0; j<table->columnCount(); j++)
-			{
-				QString s = "";
-				if( table->item(i,j) )
-					s = table->item(i,j)->text();
-				s.replace("\"","");
-				if( s=="," ) s="";
-				out << "\"" << s << "\"";
-				if( j<table->columnCount()-1 )
-					out << ",";
-			}
-			out << "\n";
-		}
-		
-		file.close();
-
-		QMaemo5InformationBox::information ( win, "Saved",
-			QMaemo5InformationBox::DefaultTimeout );
-	}
-}
-
-void CScoresheet::load()
-{
-	dlg_file->setWindowTitle("Load file");
-	dlg_file->setFileMode(QFileDialog::ExistingFile);
-	dlg_file->setAcceptMode(QFileDialog::AcceptOpen);
-	
-	QStringList fileNames;
-	if( dlg_file->exec() )
-	{
-		loadingFile = true;
-
-		fileNames = dlg_file->selectedFiles();
-		QFile file(fileNames.at(0), win);
-		if( !file.open(QIODevice::ReadOnly | QIODevice::Text) ) {
-			QMaemo5InformationBox::information ( win, "Could not open file!",
-				QMaemo5InformationBox::DefaultTimeout );
-			return;
-		}		
-		QTextStream in(&file);
-
-		bool sizeFound = false;
-		QString s = in.readLine();
-		if( s.section(',',0,0) == "ScoresheetSizeXY" ) {
-			sizeX = s.section(',',1,1).toInt();
-			sizeY = s.section(',',2,2).toInt();
-			sizeFound = true;
-		} else {
-			in.seek(0);
-		}
-		
-		if( sizeX < minSizeX || sizeX > maxSizeX )
-			sizeX = defaultSizeX;
-		if( sizeY < minSizeY || sizeY > maxSizeY )
-			sizeY = defaultSizeY;
-		
-		if( table->item(lastcellRow,lastcellCol) ) {
-			table->item(lastcellRow,lastcellCol)->setSelected(false);			
-		}
-		typing=false;
-		table->clear();
-		names.clear();
-		if( sizeFound ) {
-			for(int i=0; i<sizeX; i++)
-			{
-				QString u;
-				u.setNum(i+1);
-				names << defaultName+u;
-			}
-		}
-
-		// does not work properly if names are not enclosed in ""
-		
-		s = in.readLine();
-		QStringList sl = s.split("\",\"");
-		int count = sl.count();
-		if( !sizeFound ) {
-			if( count < minSizeX ) count = minSizeX;
-			if( count > maxSizeX ) count = maxSizeX;
-			for(int i=0; i<count; i++)
-			{
-				QString u;
-				u.setNum(i+1);
-				names << defaultName+u;
-			}
-		}
-		if (sizeFound && sizeX<count) count=sizeX;
-		for(int i=0; i<count; i++)
-		{
-			QString t = sl.at(i);
-			t.replace("\"","");
-			names[i] = t;
-		}
-		if( !sizeFound ) sizeX=names.count();
-		resizeTable();
-
-		progress->setRange(0,sizeX*sizeY);
-		progress->setValue(0);
-		keys->hide();
-		barH->hide();
-		progress->show();
-		table->setEnabled(false);
-
-		//std::cout << "sizeX is " << sizeX << std::endl;
-
-		s = in.readLine();
-		int row=0;
-     	while (!s.isNull()) {
-	     	sl.clear();
-			sl = s.split("\",\"");
-			int count = sl.count();
-			if (sizeX<count) count=sizeX;
-			for(int i=0; i<count; i++)
-			{
-				QString t = sl.at(i);
-				t.replace("\"","");
-				if( !table->item(row,i) && t.length()>0 )
-				{
-					QTableWidgetItem *item = new QTableWidgetItem();
-					table->setItem(row,i,item);
-					table->item(row,i)->setTextAlignment(Qt::AlignCenter);
-				}
-				if( t.length()>0 ) table->item(row,i)->setText(t);
-				progress->setValue(sizeX*row+i);
-			}
-			s = in.readLine();
-			row++;
-			if( row>=sizeY ) break;
-        }
-   		progress->hide();
-   		if( !hideKeys ) keys->show();
-   		else if( portrait ) barH->show();
-		table->setEnabled(true);
-
-		file.close();
-		loadingFile = false;
-		updateHeaders();
-	}
-}
-*/
-
